@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="es_ES">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es_ES">
 <context>
     <name>MainWindow</name>
     <message>
@@ -407,4 +405,4 @@
         <translation>Debe ejecutar este programa con acceso de administrador.</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
